==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/NotificationHubAuthorizationRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin

import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs.builder
import com.pulumi.azurenative.notificationhubs.kotlin.inputs.SharedAccessAuthorizationRulePropertiesArgs
import com.pulumi.azurenative.notificationhubs.kotlin.inputs.SharedAccessAuthorizationRulePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Response for POST requests that return single SharedAccessAuthorizationRule.
 * Azure REST API version: 2023-01-01-preview. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2016-03-01, 2017-04-01, 2023-09-01.
 * ## Example Usage
 * ### NotificationHubs_CreateOrUpdateAuthorizationRule
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var notificationHubAuthorizationRule = new AzureNative.NotificationHubs.NotificationHubAuthorizationRule("notificationHubAuthorizationRule", new()
 *     {
 *         AuthorizationRuleName = "MyManageSharedAccessKey",
 *         NamespaceName = "nh-sdk-ns",
 *         NotificationHubName = "nh-sdk-hub",
 *         Properties = new AzureNative.NotificationHubs.Inputs.SharedAccessAuthorizationRulePropertiesArgs
 *         {
 *             Rights = new[]
 *             {
 *                 "Listen",
 *                 "Send",
 *             },
 *         },
 *         ResourceGroupName = "5ktrial",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/notificationhubs/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := notificationhubs.NewNotificationHubAuthorizationRule(ctx, "notificationHubAuthorizationRule", &notificationhubs.NotificationHubAuthorizationRuleArgs{
 * 			AuthorizationRuleName: pulumi.String("MyManageSharedAccessKey"),
 * 			NamespaceName:         pulumi.String("nh-sdk-ns"),
 * 			NotificationHubName:   pulumi.String("nh-sdk-hub"),
 * 			Properties: &notificationhubs.SharedAccessAuthorizationRulePropertiesArgs{
 * 				Rights: pulumi.StringArray{
 * 					pulumi.String("Listen"),
 * 					pulumi.String("Send"),
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("5ktrial"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRule;
 * import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var notificationHubAuthorizationRule = new NotificationHubAuthorizationRule("notificationHubAuthorizationRule", NotificationHubAuthorizationRuleArgs.builder()
 *             .authorizationRuleName("MyManageSharedAccessKey")
 *             .namespaceName("nh-sdk-ns")
 *             .notificationHubName("nh-sdk-hub")
 *             .properties(Map.of("rights",
 *                 "Listen",
 *                 "Send"))
 *             .resourceGroupName("5ktrial")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:notificationhubs:NotificationHubAuthorizationRule MyManageSharedAccessKey /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.NotificationHubs/namespaces/{namespaceName}/notificationHubs/{notificationHubName}/authorizationRules/{authorizationRuleName}
 * ```
 * @property authorizationRuleName Authorization Rule Name
 * @property location Deprecated - only for compatibility.
 * @property namespaceName Namespace name
 * @property notificationHubName Notification Hub name
 * @property properties SharedAccessAuthorizationRule properties.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property tags Deprecated - only for compatibility.
 */
public data class NotificationHubAuthorizationRuleArgs(
    public val authorizationRuleName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val notificationHubName: Output<String>? = null,
    public val properties: Output<SharedAccessAuthorizationRulePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs =
        com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs.builder()
            .authorizationRuleName(authorizationRuleName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .notificationHubName(notificationHubName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [NotificationHubAuthorizationRuleArgs].
 */
@PulumiTagMarker
public class NotificationHubAuthorizationRuleArgsBuilder internal constructor() {
    private var authorizationRuleName: Output<String>? = null

    private var location: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var notificationHubName: Output<String>? = null

    private var properties: Output<SharedAccessAuthorizationRulePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Authorization Rule Name
     */
    @JvmName("ksnrkcqpgyfbbham")
    public suspend fun authorizationRuleName(`value`: Output<String>) {
        this.authorizationRuleName = value
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("xerkrhuqgvtwnaic")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Namespace name
     */
    @JvmName("oxlshxjtraaupxbe")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value Notification Hub name
     */
    @JvmName("nyvmrhmppgitqpds")
    public suspend fun notificationHubName(`value`: Output<String>) {
        this.notificationHubName = value
    }

    /**
     * @param value SharedAccessAuthorizationRule properties.
     */
    @JvmName("laworcasertiyyot")
    public suspend fun properties(`value`: Output<SharedAccessAuthorizationRulePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("wgklhxcwcdwajlco")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("yynjwrkbrpydnsek")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Authorization Rule Name
     */
    @JvmName("umxpsdpntnhepitj")
    public suspend fun authorizationRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizationRuleName = mapped
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("jevfpuwpjbmymbyu")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Namespace name
     */
    @JvmName("qdmwnfqroasrxcch")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value Notification Hub name
     */
    @JvmName("acecjxsduutmfbtl")
    public suspend fun notificationHubName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationHubName = mapped
    }

    /**
     * @param value SharedAccessAuthorizationRule properties.
     */
    @JvmName("egxcwhrphialffhx")
    public suspend fun properties(`value`: SharedAccessAuthorizationRulePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument SharedAccessAuthorizationRule properties.
     */
    @JvmName("aqtdlrkvyranhiiw")
    public suspend
    fun properties(argument: suspend SharedAccessAuthorizationRulePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SharedAccessAuthorizationRulePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("exbdvqvbtxlmexqm")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("wpknlnascmvfgugb")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Deprecated - only for compatibility.
     */
    @JvmName("ktbelgjbqyyotybt")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): NotificationHubAuthorizationRuleArgs = NotificationHubAuthorizationRuleArgs(
        authorizationRuleName = authorizationRuleName,
        location = location,
        namespaceName = namespaceName,
        notificationHubName = notificationHubName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/NotificationHubAuthorizationRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin

import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs.builder
import com.pulumi.azurenative.notificationhubs.kotlin.inputs.SharedAccessAuthorizationRulePropertiesArgs
import com.pulumi.azurenative.notificationhubs.kotlin.inputs.SharedAccessAuthorizationRulePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Response for POST requests that return single SharedAccessAuthorizationRule.
 * Azure REST API version: 2023-01-01-preview. Prior API version in Azure Native 1.x: 2017-04-01.
 * Other available API versions: 2016-03-01, 2017-04-01, 2023-09-01, 2023-10-01-preview.
 * ## Example Usage
 * ### NotificationHubs_CreateOrUpdateAuthorizationRule
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var notificationHubAuthorizationRule = new AzureNative.NotificationHubs.NotificationHubAuthorizationRule("notificationHubAuthorizationRule", new()
 *     {
 *         AuthorizationRuleName = "MyManageSharedAccessKey",
 *         NamespaceName = "nh-sdk-ns",
 *         NotificationHubName = "nh-sdk-hub",
 *         Properties = new AzureNative.NotificationHubs.Inputs.SharedAccessAuthorizationRulePropertiesArgs
 *         {
 *             Rights = new[]
 *             {
 *                 "Listen",
 *                 "Send",
 *             },
 *         },
 *         ResourceGroupName = "5ktrial",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/notificationhubs/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := notificationhubs.NewNotificationHubAuthorizationRule(ctx, "notificationHubAuthorizationRule", &notificationhubs.NotificationHubAuthorizationRuleArgs{
 * 			AuthorizationRuleName: pulumi.String("MyManageSharedAccessKey"),
 * 			NamespaceName:         pulumi.String("nh-sdk-ns"),
 * 			NotificationHubName:   pulumi.String("nh-sdk-hub"),
 * 			Properties: &notificationhubs.SharedAccessAuthorizationRulePropertiesArgs{
 * 				Rights: pulumi.StringArray{
 * 					pulumi.String("Listen"),
 * 					pulumi.String("Send"),
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("5ktrial"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRule;
 * import com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var notificationHubAuthorizationRule = new NotificationHubAuthorizationRule("notificationHubAuthorizationRule", NotificationHubAuthorizationRuleArgs.builder()
 *             .authorizationRuleName("MyManageSharedAccessKey")
 *             .namespaceName("nh-sdk-ns")
 *             .notificationHubName("nh-sdk-hub")
 *             .properties(Map.of("rights",
 *                 "Listen",
 *                 "Send"))
 *             .resourceGroupName("5ktrial")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:notificationhubs:NotificationHubAuthorizationRule MyManageSharedAccessKey /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.NotificationHubs/namespaces/{namespaceName}/notificationHubs/{notificationHubName}/authorizationRules/{authorizationRuleName}
 * ```
 * @property authorizationRuleName Authorization Rule Name
 * @property location Deprecated - only for compatibility.
 * @property namespaceName Namespace name
 * @property notificationHubName Notification Hub name
 * @property properties SharedAccessAuthorizationRule properties.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property tags Deprecated - only for compatibility.
 */
public data class NotificationHubAuthorizationRuleArgs(
    public val authorizationRuleName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val notificationHubName: Output<String>? = null,
    public val properties: Output<SharedAccessAuthorizationRulePropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs> {
    override fun toJava():
        com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs =
        com.pulumi.azurenative.notificationhubs.NotificationHubAuthorizationRuleArgs.builder()
            .authorizationRuleName(authorizationRuleName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .notificationHubName(notificationHubName?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [NotificationHubAuthorizationRuleArgs].
 */
@PulumiTagMarker
public class NotificationHubAuthorizationRuleArgsBuilder internal constructor() {
    private var authorizationRuleName: Output<String>? = null

    private var location: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var notificationHubName: Output<String>? = null

    private var properties: Output<SharedAccessAuthorizationRulePropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Authorization Rule Name
     */
    @JvmName("cdvymofxtgiiksjq")
    public suspend fun authorizationRuleName(`value`: Output<String>) {
        this.authorizationRuleName = value
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("ukfufoxholkeauur")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Namespace name
     */
    @JvmName("jyptdxthgetgaiye")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value Notification Hub name
     */
    @JvmName("qykclmvtkqvpwnsc")
    public suspend fun notificationHubName(`value`: Output<String>) {
        this.notificationHubName = value
    }

    /**
     * @param value SharedAccessAuthorizationRule properties.
     */
    @JvmName("tvqgyohxqeihpyua")
    public suspend fun properties(`value`: Output<SharedAccessAuthorizationRulePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("wyaldwrlrdwocpyh")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("survivpycwrrhpud")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Authorization Rule Name
     */
    @JvmName("rubgsnhtsnpcfmcg")
    public suspend fun authorizationRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authorizationRuleName = mapped
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("tlroxcmktcodxjvq")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Namespace name
     */
    @JvmName("xbapmlmgqvdmyjyv")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value Notification Hub name
     */
    @JvmName("sdsppbyelsbxruep")
    public suspend fun notificationHubName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationHubName = mapped
    }

    /**
     * @param value SharedAccessAuthorizationRule properties.
     */
    @JvmName("tkyiauxniqcbpwyu")
    public suspend fun properties(`value`: SharedAccessAuthorizationRulePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument SharedAccessAuthorizationRule properties.
     */
    @JvmName("nunivgiunuoyjbku")
    public suspend
    fun properties(argument: suspend SharedAccessAuthorizationRulePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SharedAccessAuthorizationRulePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xhdwqowbnrghwjdw")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Deprecated - only for compatibility.
     */
    @JvmName("tanvotuymijvvnyo")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Deprecated - only for compatibility.
     */
    @JvmName("qnslohaunrleytwa")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): NotificationHubAuthorizationRuleArgs = NotificationHubAuthorizationRuleArgs(
        authorizationRuleName = authorizationRuleName,
        location = location,
        namespaceName = namespaceName,
        notificationHubName = notificationHubName,
        properties = properties,
        resourceGroupName = resourceGroupName,
        tags = tags,
    )
}
